# Hexabyte Extended Info Plugin

A hexabyte plugin for displaying additional file info.

## Install

```bash
~/$ pip install hexabyte-extended-info
...
```

Add `hexabyte_extended_info` to the plugins list inside your hexabyte config (`~/.config/hexabyte/config.toml`).

```toml
plugins = [ "hexabyte_extended_info",]
```
